# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: GraphTypesService.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'GraphTypesService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import AdminService_pb2 as AdminService__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17GraphTypesService.proto\x12\x08xgtproto\x1a\x12\x41\x64minService.proto\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\"\x19\n\x08LabelSet\x12\r\n\x05label\x18\x01 \x03(\t\"\x9a\x01\n\rFrameLabelMap\x12@\n\raccess_labels\x18\x01 \x03(\x0b\x32).xgtproto.FrameLabelMap.AccessLabelsEntry\x1aG\n\x11\x41\x63\x63\x65ssLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.xgtproto.LabelSet:\x02\x38\x01\"\xa8\x02\n\x16\x43reateNamespaceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x0f\x66rame_label_map\x18\x02 \x01(\x0b\x32\x17.xgtproto.FrameLabelMap\x12<\n\x06kwargs\x18\x03 \x03(\x0b\x32,.xgtproto.CreateNamespaceRequest.KwargsEntry\x12.\n\x12row_label_universe\x18\x04 \x01(\x0b\x32\x12.xgtproto.LabelSet\x12\x1a\n\x12\x63onditional_create\x18\x05 \x01(\x08\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"9\n\x17\x43reateNamespaceResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\xbe\x01\n\x16\x44\x65leteNamespaceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nforce_drop\x18\x02 \x01(\x08\x12<\n\x06kwargs\x18\x03 \x03(\x0b\x32,.xgtproto.DeleteNamespaceRequest.KwargsEntry\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"T\n\x17\x44\x65leteNamespaceResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x19\n\x11\x66ound_and_deleted\x18\x02 \x01(\x08\"\x16\n\x14GetNamespacesRequest\"O\n\x15GetNamespacesResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x16\n\x0enamespace_name\x18\x02 \x03(\t\"\xb7\x03\n\x12\x43reateFrameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x06schema\x18\x02 \x01(\x0b\x32\x10.xgtproto.Schema\x12%\n\x04type\x18\x03 \x01(\x0e\x32\x17.xgtproto.FrameTypeEnum\x12\x12\n\nvertex_key\x18\x04 \x01(\r\x12\x12\n\nsource_key\x18\x05 \x01(\r\x12\x12\n\ntarget_key\x18\x06 \x01(\r\x12\x15\n\rsource_vertex\x18\x07 \x01(\t\x12\x15\n\rtarget_vertex\x18\x08 \x01(\t\x12\x30\n\x0f\x66rame_label_map\x18\t \x01(\x0b\x32\x17.xgtproto.FrameLabelMap\x12.\n\x12row_label_universe\x18\n \x01(\x0b\x32\x12.xgtproto.LabelSet\x12\x38\n\x06kwargs\x18\x0b \x03(\x0b\x32(.xgtproto.CreateFrameRequest.KwargsEntry\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"@\n\x18GetFramesMetadataRequest\x12\x0c\n\x04name\x18\x01 \x03(\t\x12\x16\n\x0enamespace_name\x18\x02 \x01(\t\"b\n\x19GetFramesMetadataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12%\n\tcontainer\x18\x02 \x03(\x0b\x32\x12.xgtproto.AnyFrame\"\xa4\x01\n\x13\x44\x65leteFramesRequest\x12\x0c\n\x04name\x18\x01 \x03(\t\x12\x39\n\x06kwargs\x18\x02 \x03(\x0b\x32).xgtproto.DeleteFramesRequest.KwargsEntry\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"Q\n\x14\x44\x65leteFramesResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x19\n\x11\x66ound_and_deleted\x18\x02 \x01(\x08\"F\n\x14ModifyColumnsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x06schema\x18\x02 \x01(\x0b\x32\x10.xgtproto.Schema\"7\n\x15ModifyColumnsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"#\n\x13GetFrameSizeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"D\n\x14GetFrameSizeResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x0c\n\x04size\x18\x02 \x01(\x04\"%\n\x15GetFrameSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"Z\n\x16GetFrameSchemaResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12 \n\x06schema\x18\x02 \x01(\x0b\x32\x10.xgtproto.Schema\"%\n\x15GetFrameLabelsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"j\n\x16GetFrameLabelsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x30\n\x0f\x66rame_label_map\x18\x02 \x01(\x0b\x32\x17.xgtproto.FrameLabelMap\"*\n\x1aGetRowLabelUniverseRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"e\n\x1bGetRowLabelUniverseResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12&\n\nrow_labels\x18\x02 \x01(\x0b\x32\x12.xgtproto.LabelSet\")\n\x19GetUserPermissionsRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc9\x01\n\x1aGetUserPermissionsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12S\n\x10user_permissions\x18\x02 \x03(\x0b\x32\x39.xgtproto.GetUserPermissionsResponse.UserPermissionsEntry\x1a\x36\n\x14UserPermissionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x16\n\x14GetUserLabelsRequest\"`\n\x15GetUserLabelsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\x0buser_labels\x18\x02 \x01(\x0b\x32\x12.xgtproto.LabelSet2\x9f\x0b\n\x11GraphTypesService\x12\\\n\x0fGetVertexFrames\x12\".xgtproto.GetFramesMetadataRequest\x1a#.xgtproto.GetFramesMetadataResponse\"\x00\x12Z\n\rGetEdgeFrames\x12\".xgtproto.GetFramesMetadataRequest\x1a#.xgtproto.GetFramesMetadataResponse\"\x00\x12[\n\x0eGetTableFrames\x12\".xgtproto.GetFramesMetadataRequest\x1a#.xgtproto.GetFramesMetadataResponse\"\x00\x12V\n\tGetFrames\x12\".xgtproto.GetFramesMetadataRequest\x1a#.xgtproto.GetFramesMetadataResponse\"\x00\x12X\n\x0f\x43reateNamespace\x12 .xgtproto.CreateNamespaceRequest\x1a!.xgtproto.CreateNamespaceResponse\"\x00\x12X\n\x0f\x44\x65leteNamespace\x12 .xgtproto.DeleteNamespaceRequest\x1a!.xgtproto.DeleteNamespaceResponse\"\x00\x12R\n\rGetNamespaces\x12\x1e.xgtproto.GetNamespacesRequest\x1a\x1f.xgtproto.GetNamespacesResponse\"\x00\x12R\n\x0b\x43reateFrame\x12\x1c.xgtproto.CreateFrameRequest\x1a#.xgtproto.GetFramesMetadataResponse\"\x00\x12O\n\x0c\x44\x65leteFrames\x12\x1d.xgtproto.DeleteFramesRequest\x1a\x1e.xgtproto.DeleteFramesResponse\"\x00\x12R\n\rModifyColumns\x12\x1e.xgtproto.ModifyColumnsRequest\x1a\x1f.xgtproto.ModifyColumnsResponse\"\x00\x12O\n\x0cGetFrameSize\x12\x1d.xgtproto.GetFrameSizeRequest\x1a\x1e.xgtproto.GetFrameSizeResponse\"\x00\x12U\n\x0eGetFrameSchema\x12\x1f.xgtproto.GetFrameSchemaRequest\x1a .xgtproto.GetFrameSchemaResponse\"\x00\x12U\n\x0eGetFrameLabels\x12\x1f.xgtproto.GetFrameLabelsRequest\x1a .xgtproto.GetFrameLabelsResponse\"\x00\x12\x64\n\x13GetRowLabelUniverse\x12$.xgtproto.GetRowLabelUniverseRequest\x1a%.xgtproto.GetRowLabelUniverseResponse\"\x00\x12\x61\n\x12GetUserPermissions\x12#.xgtproto.GetUserPermissionsRequest\x1a$.xgtproto.GetUserPermissionsResponse\"\x00\x12R\n\rGetUserLabels\x12\x1e.xgtproto.GetUserLabelsRequest\x1a\x1f.xgtproto.GetUserLabelsResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GraphTypesService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FRAMELABELMAP_ACCESSLABELSENTRY']._loaded_options = None
  _globals['_FRAMELABELMAP_ACCESSLABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATENAMESPACEREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_CREATENAMESPACEREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_DELETENAMESPACEREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_DELETENAMESPACEREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEFRAMEREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_CREATEFRAMEREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_DELETEFRAMESREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_DELETEFRAMESREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_GETUSERPERMISSIONSRESPONSE_USERPERMISSIONSENTRY']._loaded_options = None
  _globals['_GETUSERPERMISSIONSRESPONSE_USERPERMISSIONSENTRY']._serialized_options = b'8\001'
  _globals['_LABELSET']._serialized_start=100
  _globals['_LABELSET']._serialized_end=125
  _globals['_FRAMELABELMAP']._serialized_start=128
  _globals['_FRAMELABELMAP']._serialized_end=282
  _globals['_FRAMELABELMAP_ACCESSLABELSENTRY']._serialized_start=211
  _globals['_FRAMELABELMAP_ACCESSLABELSENTRY']._serialized_end=282
  _globals['_CREATENAMESPACEREQUEST']._serialized_start=285
  _globals['_CREATENAMESPACEREQUEST']._serialized_end=581
  _globals['_CREATENAMESPACEREQUEST_KWARGSENTRY']._serialized_start=513
  _globals['_CREATENAMESPACEREQUEST_KWARGSENTRY']._serialized_end=581
  _globals['_CREATENAMESPACERESPONSE']._serialized_start=583
  _globals['_CREATENAMESPACERESPONSE']._serialized_end=640
  _globals['_DELETENAMESPACEREQUEST']._serialized_start=643
  _globals['_DELETENAMESPACEREQUEST']._serialized_end=833
  _globals['_DELETENAMESPACEREQUEST_KWARGSENTRY']._serialized_start=513
  _globals['_DELETENAMESPACEREQUEST_KWARGSENTRY']._serialized_end=581
  _globals['_DELETENAMESPACERESPONSE']._serialized_start=835
  _globals['_DELETENAMESPACERESPONSE']._serialized_end=919
  _globals['_GETNAMESPACESREQUEST']._serialized_start=921
  _globals['_GETNAMESPACESREQUEST']._serialized_end=943
  _globals['_GETNAMESPACESRESPONSE']._serialized_start=945
  _globals['_GETNAMESPACESRESPONSE']._serialized_end=1024
  _globals['_CREATEFRAMEREQUEST']._serialized_start=1027
  _globals['_CREATEFRAMEREQUEST']._serialized_end=1466
  _globals['_CREATEFRAMEREQUEST_KWARGSENTRY']._serialized_start=513
  _globals['_CREATEFRAMEREQUEST_KWARGSENTRY']._serialized_end=581
  _globals['_GETFRAMESMETADATAREQUEST']._serialized_start=1468
  _globals['_GETFRAMESMETADATAREQUEST']._serialized_end=1532
  _globals['_GETFRAMESMETADATARESPONSE']._serialized_start=1534
  _globals['_GETFRAMESMETADATARESPONSE']._serialized_end=1632
  _globals['_DELETEFRAMESREQUEST']._serialized_start=1635
  _globals['_DELETEFRAMESREQUEST']._serialized_end=1799
  _globals['_DELETEFRAMESREQUEST_KWARGSENTRY']._serialized_start=513
  _globals['_DELETEFRAMESREQUEST_KWARGSENTRY']._serialized_end=581
  _globals['_DELETEFRAMESRESPONSE']._serialized_start=1801
  _globals['_DELETEFRAMESRESPONSE']._serialized_end=1882
  _globals['_MODIFYCOLUMNSREQUEST']._serialized_start=1884
  _globals['_MODIFYCOLUMNSREQUEST']._serialized_end=1954
  _globals['_MODIFYCOLUMNSRESPONSE']._serialized_start=1956
  _globals['_MODIFYCOLUMNSRESPONSE']._serialized_end=2011
  _globals['_GETFRAMESIZEREQUEST']._serialized_start=2013
  _globals['_GETFRAMESIZEREQUEST']._serialized_end=2048
  _globals['_GETFRAMESIZERESPONSE']._serialized_start=2050
  _globals['_GETFRAMESIZERESPONSE']._serialized_end=2118
  _globals['_GETFRAMESCHEMAREQUEST']._serialized_start=2120
  _globals['_GETFRAMESCHEMAREQUEST']._serialized_end=2157
  _globals['_GETFRAMESCHEMARESPONSE']._serialized_start=2159
  _globals['_GETFRAMESCHEMARESPONSE']._serialized_end=2249
  _globals['_GETFRAMELABELSREQUEST']._serialized_start=2251
  _globals['_GETFRAMELABELSREQUEST']._serialized_end=2288
  _globals['_GETFRAMELABELSRESPONSE']._serialized_start=2290
  _globals['_GETFRAMELABELSRESPONSE']._serialized_end=2396
  _globals['_GETROWLABELUNIVERSEREQUEST']._serialized_start=2398
  _globals['_GETROWLABELUNIVERSEREQUEST']._serialized_end=2440
  _globals['_GETROWLABELUNIVERSERESPONSE']._serialized_start=2442
  _globals['_GETROWLABELUNIVERSERESPONSE']._serialized_end=2543
  _globals['_GETUSERPERMISSIONSREQUEST']._serialized_start=2545
  _globals['_GETUSERPERMISSIONSREQUEST']._serialized_end=2586
  _globals['_GETUSERPERMISSIONSRESPONSE']._serialized_start=2589
  _globals['_GETUSERPERMISSIONSRESPONSE']._serialized_end=2790
  _globals['_GETUSERPERMISSIONSRESPONSE_USERPERMISSIONSENTRY']._serialized_start=2736
  _globals['_GETUSERPERMISSIONSRESPONSE_USERPERMISSIONSENTRY']._serialized_end=2790
  _globals['_GETUSERLABELSREQUEST']._serialized_start=2792
  _globals['_GETUSERLABELSREQUEST']._serialized_end=2814
  _globals['_GETUSERLABELSRESPONSE']._serialized_start=2816
  _globals['_GETUSERLABELSRESPONSE']._serialized_end=2912
  _globals['_GRAPHTYPESSERVICE']._serialized_start=2915
  _globals['_GRAPHTYPESSERVICE']._serialized_end=4354
# @@protoc_insertion_point(module_scope)
