# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import GraphTypesService_pb2 as GraphTypesService__pb2


class GraphTypesServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetVertexFrames = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetVertexFrames',
                request_serializer=GraphTypesService__pb2.GetFramesMetadataRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
                _registered_method=True)
        self.GetEdgeFrames = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetEdgeFrames',
                request_serializer=GraphTypesService__pb2.GetFramesMetadataRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
                _registered_method=True)
        self.GetTableFrames = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetTableFrames',
                request_serializer=GraphTypesService__pb2.GetFramesMetadataRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
                _registered_method=True)
        self.GetFrames = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetFrames',
                request_serializer=GraphTypesService__pb2.GetFramesMetadataRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
                _registered_method=True)
        self.CreateNamespace = channel.unary_unary(
                '/xgtproto.GraphTypesService/CreateNamespace',
                request_serializer=GraphTypesService__pb2.CreateNamespaceRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.CreateNamespaceResponse.FromString,
                _registered_method=True)
        self.DeleteNamespace = channel.unary_unary(
                '/xgtproto.GraphTypesService/DeleteNamespace',
                request_serializer=GraphTypesService__pb2.DeleteNamespaceRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.DeleteNamespaceResponse.FromString,
                _registered_method=True)
        self.GetNamespaces = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetNamespaces',
                request_serializer=GraphTypesService__pb2.GetNamespacesRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetNamespacesResponse.FromString,
                _registered_method=True)
        self.CreateFrame = channel.unary_unary(
                '/xgtproto.GraphTypesService/CreateFrame',
                request_serializer=GraphTypesService__pb2.CreateFrameRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
                _registered_method=True)
        self.DeleteFrames = channel.unary_unary(
                '/xgtproto.GraphTypesService/DeleteFrames',
                request_serializer=GraphTypesService__pb2.DeleteFramesRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.DeleteFramesResponse.FromString,
                _registered_method=True)
        self.ModifyColumns = channel.unary_unary(
                '/xgtproto.GraphTypesService/ModifyColumns',
                request_serializer=GraphTypesService__pb2.ModifyColumnsRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.ModifyColumnsResponse.FromString,
                _registered_method=True)
        self.GetFrameSize = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetFrameSize',
                request_serializer=GraphTypesService__pb2.GetFrameSizeRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetFrameSizeResponse.FromString,
                _registered_method=True)
        self.GetFrameSchema = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetFrameSchema',
                request_serializer=GraphTypesService__pb2.GetFrameSchemaRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetFrameSchemaResponse.FromString,
                _registered_method=True)
        self.GetFrameLabels = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetFrameLabels',
                request_serializer=GraphTypesService__pb2.GetFrameLabelsRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetFrameLabelsResponse.FromString,
                _registered_method=True)
        self.GetRowLabelUniverse = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetRowLabelUniverse',
                request_serializer=GraphTypesService__pb2.GetRowLabelUniverseRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetRowLabelUniverseResponse.FromString,
                _registered_method=True)
        self.GetUserPermissions = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetUserPermissions',
                request_serializer=GraphTypesService__pb2.GetUserPermissionsRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetUserPermissionsResponse.FromString,
                _registered_method=True)
        self.GetUserLabels = channel.unary_unary(
                '/xgtproto.GraphTypesService/GetUserLabels',
                request_serializer=GraphTypesService__pb2.GetUserLabelsRequest.SerializeToString,
                response_deserializer=GraphTypesService__pb2.GetUserLabelsResponse.FromString,
                _registered_method=True)


class GraphTypesServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetVertexFrames(self, request, context):
        """Vertex frames.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEdgeFrames(self, request, context):
        """Edge frames.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTableFrames(self, request, context):
        """Table frames.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFrames(self, request, context):
        """Any frames.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNamespace(self, request, context):
        """Namespaces functions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNamespace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNamespaces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFrame(self, request, context):
        """Multi-type functions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFrames(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ModifyColumns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFrameSize(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFrameSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFrameLabels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRowLabelUniverse(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserPermissions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserLabels(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GraphTypesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetVertexFrames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVertexFrames,
                    request_deserializer=GraphTypesService__pb2.GetFramesMetadataRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetFramesMetadataResponse.SerializeToString,
            ),
            'GetEdgeFrames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEdgeFrames,
                    request_deserializer=GraphTypesService__pb2.GetFramesMetadataRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetFramesMetadataResponse.SerializeToString,
            ),
            'GetTableFrames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTableFrames,
                    request_deserializer=GraphTypesService__pb2.GetFramesMetadataRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetFramesMetadataResponse.SerializeToString,
            ),
            'GetFrames': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFrames,
                    request_deserializer=GraphTypesService__pb2.GetFramesMetadataRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetFramesMetadataResponse.SerializeToString,
            ),
            'CreateNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNamespace,
                    request_deserializer=GraphTypesService__pb2.CreateNamespaceRequest.FromString,
                    response_serializer=GraphTypesService__pb2.CreateNamespaceResponse.SerializeToString,
            ),
            'DeleteNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNamespace,
                    request_deserializer=GraphTypesService__pb2.DeleteNamespaceRequest.FromString,
                    response_serializer=GraphTypesService__pb2.DeleteNamespaceResponse.SerializeToString,
            ),
            'GetNamespaces': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNamespaces,
                    request_deserializer=GraphTypesService__pb2.GetNamespacesRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetNamespacesResponse.SerializeToString,
            ),
            'CreateFrame': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFrame,
                    request_deserializer=GraphTypesService__pb2.CreateFrameRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetFramesMetadataResponse.SerializeToString,
            ),
            'DeleteFrames': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFrames,
                    request_deserializer=GraphTypesService__pb2.DeleteFramesRequest.FromString,
                    response_serializer=GraphTypesService__pb2.DeleteFramesResponse.SerializeToString,
            ),
            'ModifyColumns': grpc.unary_unary_rpc_method_handler(
                    servicer.ModifyColumns,
                    request_deserializer=GraphTypesService__pb2.ModifyColumnsRequest.FromString,
                    response_serializer=GraphTypesService__pb2.ModifyColumnsResponse.SerializeToString,
            ),
            'GetFrameSize': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFrameSize,
                    request_deserializer=GraphTypesService__pb2.GetFrameSizeRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetFrameSizeResponse.SerializeToString,
            ),
            'GetFrameSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFrameSchema,
                    request_deserializer=GraphTypesService__pb2.GetFrameSchemaRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetFrameSchemaResponse.SerializeToString,
            ),
            'GetFrameLabels': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFrameLabels,
                    request_deserializer=GraphTypesService__pb2.GetFrameLabelsRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetFrameLabelsResponse.SerializeToString,
            ),
            'GetRowLabelUniverse': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRowLabelUniverse,
                    request_deserializer=GraphTypesService__pb2.GetRowLabelUniverseRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetRowLabelUniverseResponse.SerializeToString,
            ),
            'GetUserPermissions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserPermissions,
                    request_deserializer=GraphTypesService__pb2.GetUserPermissionsRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetUserPermissionsResponse.SerializeToString,
            ),
            'GetUserLabels': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserLabels,
                    request_deserializer=GraphTypesService__pb2.GetUserLabelsRequest.FromString,
                    response_serializer=GraphTypesService__pb2.GetUserLabelsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'xgtproto.GraphTypesService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('xgtproto.GraphTypesService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class GraphTypesService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetVertexFrames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetVertexFrames',
            GraphTypesService__pb2.GetFramesMetadataRequest.SerializeToString,
            GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetEdgeFrames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetEdgeFrames',
            GraphTypesService__pb2.GetFramesMetadataRequest.SerializeToString,
            GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTableFrames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetTableFrames',
            GraphTypesService__pb2.GetFramesMetadataRequest.SerializeToString,
            GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFrames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetFrames',
            GraphTypesService__pb2.GetFramesMetadataRequest.SerializeToString,
            GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/CreateNamespace',
            GraphTypesService__pb2.CreateNamespaceRequest.SerializeToString,
            GraphTypesService__pb2.CreateNamespaceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/DeleteNamespace',
            GraphTypesService__pb2.DeleteNamespaceRequest.SerializeToString,
            GraphTypesService__pb2.DeleteNamespaceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNamespaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetNamespaces',
            GraphTypesService__pb2.GetNamespacesRequest.SerializeToString,
            GraphTypesService__pb2.GetNamespacesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateFrame(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/CreateFrame',
            GraphTypesService__pb2.CreateFrameRequest.SerializeToString,
            GraphTypesService__pb2.GetFramesMetadataResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteFrames(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/DeleteFrames',
            GraphTypesService__pb2.DeleteFramesRequest.SerializeToString,
            GraphTypesService__pb2.DeleteFramesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ModifyColumns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/ModifyColumns',
            GraphTypesService__pb2.ModifyColumnsRequest.SerializeToString,
            GraphTypesService__pb2.ModifyColumnsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFrameSize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetFrameSize',
            GraphTypesService__pb2.GetFrameSizeRequest.SerializeToString,
            GraphTypesService__pb2.GetFrameSizeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFrameSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetFrameSchema',
            GraphTypesService__pb2.GetFrameSchemaRequest.SerializeToString,
            GraphTypesService__pb2.GetFrameSchemaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetFrameLabels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetFrameLabels',
            GraphTypesService__pb2.GetFrameLabelsRequest.SerializeToString,
            GraphTypesService__pb2.GetFrameLabelsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetRowLabelUniverse(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetRowLabelUniverse',
            GraphTypesService__pb2.GetRowLabelUniverseRequest.SerializeToString,
            GraphTypesService__pb2.GetRowLabelUniverseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserPermissions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetUserPermissions',
            GraphTypesService__pb2.GetUserPermissionsRequest.SerializeToString,
            GraphTypesService__pb2.GetUserPermissionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUserLabels(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/xgtproto.GraphTypesService/GetUserLabels',
            GraphTypesService__pb2.GetUserLabelsRequest.SerializeToString,
            GraphTypesService__pb2.GetUserLabelsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
