# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: SchemaMessages.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'SchemaMessages.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14SchemaMessages.proto\x12\x08xgtproto\x1a\x13\x45rrorMessages.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x82\x01\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\tdata_type\x18\x02 \x01(\x0e\x32\x16.xgtproto.UvalTypeEnum\x12)\n\tleaf_type\x18\x03 \x01(\x0e\x32\x16.xgtproto.UvalTypeEnum\x12\x12\n\nlist_depth\x18\x04 \x01(\x04\".\n\x06Schema\x12$\n\x08property\x18\x01 \x03(\x0b\x32\x12.xgtproto.Property\"\x87\x02\n\x08\x41nyFrame\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x06schema\x18\x02 \x01(\x0b\x32\x10.xgtproto.Schema\x12%\n\x04type\x18\x03 \x01(\x0e\x32\x17.xgtproto.FrameTypeEnum\x12\x12\n\nvertex_key\x18\x04 \x01(\t\x12\x12\n\nsource_key\x18\x05 \x01(\t\x12\x12\n\ntarget_key\x18\x06 \x01(\t\x12\x15\n\rsource_vertex\x18\x07 \x01(\t\x12\x15\n\rtarget_vertex\x18\x08 \x01(\t\x12\x14\n\x0c\x63ontainer_id\x18\t \x01(\x04\x12\x11\n\tcommit_id\x18\n \x01(\x04\x12\x11\n\tdelete_id\x18\x0b \x01(\x04\"\xc8\x01\n\x10QueryEdgeMessage\x12\x34\n\x0e\x65\x64ge_direction\x18\x01 \x01(\x0e\x32\x1c.xgtproto.QueryEdgeDirection\x12\x12\n\nedge_label\x18\x02 \x01(\t\x12\x12\n\nedge_frame\x18\x03 \x01(\t\x12\x14\n\x0csource_label\x18\x04 \x01(\t\x12\x14\n\x0csource_frame\x18\x05 \x01(\t\x12\x14\n\x0ctarget_label\x18\x06 \x01(\t\x12\x14\n\x0ctarget_frame\x18\x07 \x01(\t\"b\n\rQueryEdgeList\x12)\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.xgtproto.QueryEdgeMessage\x12\x17\n\nplan_score\x18\x02 \x01(\x01H\x00\x88\x01\x01\x42\r\n\x0b_plan_score\"?\n\tQueryPlan\x12\x32\n\x11plan_as_edge_list\x18\x01 \x03(\x0b\x32\x17.xgtproto.QueryEdgeList\"\xaa\x04\n\tJobStatus\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x0e\n\x06job_id\x18\x02 \x01(\x04\x12\'\n\x06status\x18\x03 \x01(\x0e\x32\x17.xgtproto.JobStatusEnum\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12<\n\rvisited_edges\x18\x08 \x03(\x0b\x32%.xgtproto.JobStatus.VisitedEdgesEntry\x12\x0e\n\x06timing\x18\t \x03(\t\x12 \n\x06schema\x18\n \x01(\x0b\x32\x10.xgtproto.Schema\x12\x10\n\x08num_rows\x18\x0b \x01(\x04\x12\'\n\nquery_plan\x18\x0c \x01(\x0b\x32\x13.xgtproto.QueryPlan\x12\x1b\n\x13total_ingest_errors\x18\r \x01(\x04\x12\x14\n\x0cingest_error\x18\x0e \x03(\t\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x0f \x01(\t\x12\x15\n\rresults_frame\x18\x10 \x01(\t\x1a\x33\n\x11VisitedEdgesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01*\xfc\x01\n\x0cUvalTypeEnum\x12\x15\n\x11UNKNOWN_UVAL_TYPE\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07\x42OOLEAN\x10\x02\x12\x07\n\x03INT\x10\x03\x12\t\n\x05\x46LOAT\x10\x04\x12\x08\n\x04\x44\x41TE\x10\x05\x12\x08\n\x04TIME\x10\x06\x12\x0c\n\x08\x44\x41TETIME\x10\x07\x12\r\n\tIPADDRESS\x10\x08\x12\x08\n\x04TEXT\x10\t\x12\x10\n\x0c\x43ONTAINER_ID\x10\n\x12\n\n\x06JOB_ID\x10\x0b\x12\x08\n\x04LIST\x10\x0c\x12\n\n\x06ROW_ID\x10\r\x12\x0c\n\x08\x44URATION\x10\x0e\x12\x08\n\x04UINT\x10\x0f\x12\x0c\n\x08WGSPOINT\x10\x10\x12\x12\n\x0e\x43\x41RTESIANPOINT\x10\x11*A\n\rFrameTypeEnum\x12\t\n\x05TABLE\x10\x00\x12\n\n\x06VERTEX\x10\x01\x12\x08\n\x04\x45\x44GE\x10\x02\x12\x0f\n\x0b\x41SSOCIATIVE\x10\x03*z\n\rJobStatusEnum\x12\x16\n\x12UNKNOWN_JOB_STATUS\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x0c\n\x08ROLLBACK\x10\x06*=\n\x12QueryEdgeDirection\x12\x0b\n\x07\x46ORWARD\x10\x00\x12\x0c\n\x08\x42\x41\x43KWARD\x10\x01\x12\x0c\n\x08NOT_EDGE\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SchemaMessages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_JOBSTATUS_VISITEDEDGESENTRY']._loaded_options = None
  _globals['_JOBSTATUS_VISITEDEDGESENTRY']._serialized_options = b'8\001'
  _globals['_UVALTYPEENUM']._serialized_start=1461
  _globals['_UVALTYPEENUM']._serialized_end=1713
  _globals['_FRAMETYPEENUM']._serialized_start=1715
  _globals['_FRAMETYPEENUM']._serialized_end=1780
  _globals['_JOBSTATUSENUM']._serialized_start=1782
  _globals['_JOBSTATUSENUM']._serialized_end=1904
  _globals['_QUERYEDGEDIRECTION']._serialized_start=1906
  _globals['_QUERYEDGEDIRECTION']._serialized_end=1967
  _globals['_PROPERTY']._serialized_start=89
  _globals['_PROPERTY']._serialized_end=219
  _globals['_SCHEMA']._serialized_start=221
  _globals['_SCHEMA']._serialized_end=267
  _globals['_ANYFRAME']._serialized_start=270
  _globals['_ANYFRAME']._serialized_end=533
  _globals['_QUERYEDGEMESSAGE']._serialized_start=536
  _globals['_QUERYEDGEMESSAGE']._serialized_end=736
  _globals['_QUERYEDGELIST']._serialized_start=738
  _globals['_QUERYEDGELIST']._serialized_end=836
  _globals['_QUERYPLAN']._serialized_start=838
  _globals['_QUERYPLAN']._serialized_end=901
  _globals['_JOBSTATUS']._serialized_start=904
  _globals['_JOBSTATUS']._serialized_end=1458
  _globals['_JOBSTATUS_VISITEDEDGESENTRY']._serialized_start=1407
  _globals['_JOBSTATUS_VISITEDEDGESENTRY']._serialized_end=1458
# @@protoc_insertion_point(module_scope)
