# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: JobService.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'JobService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import AdminService_pb2 as AdminService__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10JobService.proto\x12\x08xgtproto\x1a\x12\x41\x64minService.proto\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\"\xce\x02\n\x19ScheduleJobsCypherRequest\x12\x14\n\x0c\x63ypher_query\x18\x01 \x03(\t\x12?\n\x06kwargs\x18\x05 \x03(\x0b\x32/.xgtproto.ScheduleJobsCypherRequest.KwargsEntry\x12G\n\nparameters\x18\x06 \x03(\x0b\x32\x33.xgtproto.ScheduleJobsCypherRequest.ParametersEntry\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\x1aK\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.xgtproto.ParameterValue:\x02\x38\x01\"e\n\x1aScheduleJobsCypherResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x03(\x0b\x32\x13.xgtproto.JobStatus\"#\n\x11\x43\x61ncelJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\"]\n\x12\x43\x61ncelJobsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x03(\x0b\x32\x13.xgtproto.JobStatus\" \n\x0eGetJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\"Z\n\x0fGetJobsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"2\n\x0fWaitJobsRequest\x12\x0e\n\x06job_id\x18\x01 \x03(\x04\x12\x0f\n\x07timeout\x18\x02 \x01(\x03\"[\n\x10WaitJobsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x03(\x0b\x32\x13.xgtproto.JobStatus\"\xb5\x02\n\x13\x43ompileQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x39\n\x06kwargs\x18\x02 \x03(\x0b\x32).xgtproto.CompileQueryRequest.KwargsEntry\x12\x41\n\nparameters\x18\x03 \x03(\x0b\x32-.xgtproto.CompileQueryRequest.ParametersEntry\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\x1aK\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.xgtproto.ParameterValue:\x02\x38\x01\"6\n\x14\x43ompileQueryResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error2\x94\x03\n\nJobService\x12\x61\n\x12ScheduleJobsCypher\x12#.xgtproto.ScheduleJobsCypherRequest\x1a$.xgtproto.ScheduleJobsCypherResponse\"\x00\x12I\n\nCancelJobs\x12\x1b.xgtproto.CancelJobsRequest\x1a\x1c.xgtproto.CancelJobsResponse\"\x00\x12\x42\n\x07GetJobs\x12\x18.xgtproto.GetJobsRequest\x1a\x19.xgtproto.GetJobsResponse\"\x00\x30\x01\x12\x43\n\x08WaitJobs\x12\x19.xgtproto.WaitJobsRequest\x1a\x1a.xgtproto.WaitJobsResponse\"\x00\x12O\n\x0c\x43ompileQuery\x12\x1d.xgtproto.CompileQueryRequest\x1a\x1e.xgtproto.CompileQueryResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'JobService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_COMPILEQUERYREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_COMPILEQUERYREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_COMPILEQUERYREQUEST_PARAMETERSENTRY']._loaded_options = None
  _globals['_COMPILEQUERYREQUEST_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_SCHEDULEJOBSCYPHERREQUEST']._serialized_start=94
  _globals['_SCHEDULEJOBSCYPHERREQUEST']._serialized_end=428
  _globals['_SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY']._serialized_start=283
  _globals['_SCHEDULEJOBSCYPHERREQUEST_KWARGSENTRY']._serialized_end=351
  _globals['_SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY']._serialized_start=353
  _globals['_SCHEDULEJOBSCYPHERREQUEST_PARAMETERSENTRY']._serialized_end=428
  _globals['_SCHEDULEJOBSCYPHERRESPONSE']._serialized_start=430
  _globals['_SCHEDULEJOBSCYPHERRESPONSE']._serialized_end=531
  _globals['_CANCELJOBSREQUEST']._serialized_start=533
  _globals['_CANCELJOBSREQUEST']._serialized_end=568
  _globals['_CANCELJOBSRESPONSE']._serialized_start=570
  _globals['_CANCELJOBSRESPONSE']._serialized_end=663
  _globals['_GETJOBSREQUEST']._serialized_start=665
  _globals['_GETJOBSREQUEST']._serialized_end=697
  _globals['_GETJOBSRESPONSE']._serialized_start=699
  _globals['_GETJOBSRESPONSE']._serialized_end=789
  _globals['_WAITJOBSREQUEST']._serialized_start=791
  _globals['_WAITJOBSREQUEST']._serialized_end=841
  _globals['_WAITJOBSRESPONSE']._serialized_start=843
  _globals['_WAITJOBSRESPONSE']._serialized_end=934
  _globals['_COMPILEQUERYREQUEST']._serialized_start=937
  _globals['_COMPILEQUERYREQUEST']._serialized_end=1246
  _globals['_COMPILEQUERYREQUEST_KWARGSENTRY']._serialized_start=283
  _globals['_COMPILEQUERYREQUEST_KWARGSENTRY']._serialized_end=351
  _globals['_COMPILEQUERYREQUEST_PARAMETERSENTRY']._serialized_start=353
  _globals['_COMPILEQUERYREQUEST_PARAMETERSENTRY']._serialized_end=428
  _globals['_COMPILEQUERYRESPONSE']._serialized_start=1248
  _globals['_COMPILEQUERYRESPONSE']._serialized_end=1302
  _globals['_JOBSERVICE']._serialized_start=1305
  _globals['_JOBSERVICE']._serialized_end=1709
# @@protoc_insertion_point(module_scope)
