# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: AdminService.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'AdminService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x41\x64minService.proto\x12\x08xgtproto\x1a\x13\x45rrorMessages.proto\"#\n\x0bStringArray\x12\x14\n\x0cstring_value\x18\x01 \x03(\t\"\x15\n\x04\x44\x61te\x12\r\n\x05value\x18\x01 \x01(\t\"\x15\n\x04Time\x12\r\n\x05value\x18\x01 \x01(\t\"\x19\n\x08\x44\x61teTime\x12\r\n\x05value\x18\x01 \x01(\t\"\x19\n\x08\x44uration\x12\r\n\x05value\x18\x01 \x01(\t\"\x1a\n\tIPAddress\x12\r\n\x05value\x18\x01 \x01(\t\".\n\x05RowID\x12\x0e\n\x06row_id\x18\x01 \x01(\x04\x12\x15\n\rvalidation_id\x18\x02 \x01(\x04\"\xef\x02\n\tParameter\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x12$\n\ndate_value\x18\x05 \x01(\x0b\x32\x0e.xgtproto.DateH\x00\x12$\n\ntime_value\x18\x06 \x01(\x0b\x32\x0e.xgtproto.TimeH\x00\x12,\n\x0e\x64\x61tetime_value\x18\x07 \x01(\x0b\x32\x12.xgtproto.DateTimeH\x00\x12,\n\x0e\x64uration_value\x18\x08 \x01(\x0b\x32\x12.xgtproto.DurationH\x00\x12.\n\x0fipaddress_value\x18\t \x01(\x0b\x32\x13.xgtproto.IPAddressH\x00\x12\'\n\x0crow_id_value\x18\n \x01(\x0b\x32\x0f.xgtproto.RowIDH\x00\x42\x07\n\x05value\"4\n\x0eParameterValue\x12\"\n\x05value\x18\x01 \x03(\x0b\x32\x13.xgtproto.Parameter\"p\n\x0b\x43onfigValue\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x04 \x01(\tH\x00\x42\x07\n\x05value\"I\n\x17\x43hangeErrorCountRequest\x12.\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x1e.xgtproto.ErrorCountActionEnum\"O\n\x18\x43hangeErrorCountResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x13\n\x0b\x65rror_count\x18\x02 \x01(\x05\"\x1b\n\x19\x46reeUserMemorySizeRequest\"V\n\x1a\x46reeUserMemorySizeResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x18\n\x10\x66ree_memory_size\x18\x02 \x01(\x03\"\x1a\n\x18MaxUserMemorySizeRequest\"N\n\x19MaxUserMemorySizeResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x11\n\tpool_size\x18\x02 \x01(\x03\" \n\x0fShutdownRequest\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\"2\n\x10ShutdownResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\x10\n\x0eVersionRequest\"[\n\x0fVersionResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x17\n\x0f\x65xpiration_date\x18\x03 \x01(\t\">\n\x0fProtocolVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05patch\x18\x03 \x01(\x05\"\x81\x01\n\x13\x41uthenticateRequest\x12\x13\n\x0b\x63redentials\x18\x01 \x01(\t\x12\x0e\n\x06userid\x18\x02 \x01(\t\x12\x10\n\x08pki_cert\x18\x03 \x01(\x0c\x12\x33\n\x10protocol_version\x18\x04 \x01(\x0b\x32\x19.xgtproto.ProtocolVersion\"\x92\x01\n\x14\x41uthenticateResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x0e\n\x06userid\x18\x03 \x01(\t\x12\x33\n\x10protocol_version\x18\x04 \x01(\x0b\x32\x19.xgtproto.ProtocolVersion\"|\n\x1bKerberosAuthenticateRequest\x12\x11\n\tkrb_token\x18\x01 \x01(\x0c\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x33\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x19.xgtproto.ProtocolVersion\"\xad\x01\n\x1cKerberosAuthenticateResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x15\n\rsession_token\x18\x02 \x01(\t\x12\x11\n\tkrb_token\x18\x03 \x01(\x0c\x12\x0e\n\x06userid\x18\x04 \x01(\t\x12\x33\n\x10protocol_version\x18\x05 \x01(\x0b\x32\x19.xgtproto.ProtocolVersion\"\x15\n\x13\x43loseSessionRequest\"6\n\x14\x43loseSessionResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\x19\n\x17KeepAliveSessionRequest\":\n\x18KeepAliveSessionResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\x1f\n\x10GetConfigRequest\x12\x0b\n\x03key\x18\x01 \x03(\t\"\xb5\x01\n\x11GetConfigResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x39\n\x07\x65ntries\x18\x02 \x03(\x0b\x32(.xgtproto.GetConfigResponse.EntriesEntry\x1a\x45\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"\x93\x01\n\x10SetConfigRequest\x12\x38\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\'.xgtproto.SetConfigRequest.EntriesEntry\x1a\x45\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"3\n\x11SetConfigResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"7\n\x1aSetDefaultNamespaceRequest\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x01 \x01(\t\"=\n\x1bSetDefaultNamespaceResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\"\x1c\n\x1aGetDefaultNamespaceRequest\"X\n\x1bGetDefaultNamespaceResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x19\n\x11\x64\x65\x66\x61ult_namespace\x18\x02 \x01(\t\"\x10\n\x0eIsAdminRequest\"C\n\x0fIsAdminResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x10\n\x08is_admin\x18\x02 \x01(\x08*T\n\x14\x45rrorCountActionEnum\x12\x1e\n\x1aUNKNOWN_ERROR_COUNT_ACTION\x10\x00\x12\r\n\tINCREMENT\x10\x01\x12\r\n\tDECREMENT\x10\x02\x32\xe8\n\n\x0c\x41\x64minService\x12[\n\x10\x43hangeErrorCount\x12!.xgtproto.ChangeErrorCountRequest\x1a\".xgtproto.ChangeErrorCountResponse\"\x00\x12\x61\n\x12\x46reeUserMemorySize\x12#.xgtproto.FreeUserMemorySizeRequest\x1a$.xgtproto.FreeUserMemorySizeResponse\"\x00\x12^\n\x11MaxUserMemorySize\x12\".xgtproto.MaxUserMemorySizeRequest\x1a#.xgtproto.MaxUserMemorySizeResponse\"\x00\x12\x43\n\x08Shutdown\x12\x19.xgtproto.ShutdownRequest\x1a\x1a.xgtproto.ShutdownResponse\"\x00\x12@\n\x07Version\x12\x18.xgtproto.VersionRequest\x1a\x19.xgtproto.VersionResponse\"\x00\x12O\n\x0c\x41uthenticate\x12\x1d.xgtproto.AuthenticateRequest\x1a\x1e.xgtproto.AuthenticateResponse\"\x00\x12R\n\x0fPKIAuthenticate\x12\x1d.xgtproto.AuthenticateRequest\x1a\x1e.xgtproto.AuthenticateResponse\"\x00\x12W\n\x14ProxyPKIAuthenticate\x12\x1d.xgtproto.AuthenticateRequest\x1a\x1e.xgtproto.AuthenticateResponse\"\x00\x12g\n\x14KerberosAuthenticate\x12%.xgtproto.KerberosAuthenticateRequest\x1a&.xgtproto.KerberosAuthenticateResponse\"\x00\x12O\n\x0c\x43loseSession\x12\x1d.xgtproto.CloseSessionRequest\x1a\x1e.xgtproto.CloseSessionResponse\"\x00\x12[\n\x10KeepAliveSession\x12!.xgtproto.KeepAliveSessionRequest\x1a\".xgtproto.KeepAliveSessionResponse\"\x00\x12\x46\n\tGetConfig\x12\x1a.xgtproto.GetConfigRequest\x1a\x1b.xgtproto.GetConfigResponse\"\x00\x12\x46\n\tSetConfig\x12\x1a.xgtproto.SetConfigRequest\x1a\x1b.xgtproto.SetConfigResponse\"\x00\x12\x64\n\x13SetDefaultNamespace\x12$.xgtproto.SetDefaultNamespaceRequest\x1a%.xgtproto.SetDefaultNamespaceResponse\"\x00\x12\x64\n\x13GetDefaultNamespace\x12$.xgtproto.GetDefaultNamespaceRequest\x1a%.xgtproto.GetDefaultNamespaceResponse\"\x00\x12@\n\x07IsAdmin\x12\x18.xgtproto.IsAdminRequest\x1a\x19.xgtproto.IsAdminResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AdminService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETCONFIGRESPONSE_ENTRIESENTRY']._loaded_options = None
  _globals['_GETCONFIGRESPONSE_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_SETCONFIGREQUEST_ENTRIESENTRY']._loaded_options = None
  _globals['_SETCONFIGREQUEST_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_ERRORCOUNTACTIONENUM']._serialized_start=2942
  _globals['_ERRORCOUNTACTIONENUM']._serialized_end=3026
  _globals['_STRINGARRAY']._serialized_start=53
  _globals['_STRINGARRAY']._serialized_end=88
  _globals['_DATE']._serialized_start=90
  _globals['_DATE']._serialized_end=111
  _globals['_TIME']._serialized_start=113
  _globals['_TIME']._serialized_end=134
  _globals['_DATETIME']._serialized_start=136
  _globals['_DATETIME']._serialized_end=161
  _globals['_DURATION']._serialized_start=163
  _globals['_DURATION']._serialized_end=188
  _globals['_IPADDRESS']._serialized_start=190
  _globals['_IPADDRESS']._serialized_end=216
  _globals['_ROWID']._serialized_start=218
  _globals['_ROWID']._serialized_end=264
  _globals['_PARAMETER']._serialized_start=267
  _globals['_PARAMETER']._serialized_end=634
  _globals['_PARAMETERVALUE']._serialized_start=636
  _globals['_PARAMETERVALUE']._serialized_end=688
  _globals['_CONFIGVALUE']._serialized_start=690
  _globals['_CONFIGVALUE']._serialized_end=802
  _globals['_CHANGEERRORCOUNTREQUEST']._serialized_start=804
  _globals['_CHANGEERRORCOUNTREQUEST']._serialized_end=877
  _globals['_CHANGEERRORCOUNTRESPONSE']._serialized_start=879
  _globals['_CHANGEERRORCOUNTRESPONSE']._serialized_end=958
  _globals['_FREEUSERMEMORYSIZEREQUEST']._serialized_start=960
  _globals['_FREEUSERMEMORYSIZEREQUEST']._serialized_end=987
  _globals['_FREEUSERMEMORYSIZERESPONSE']._serialized_start=989
  _globals['_FREEUSERMEMORYSIZERESPONSE']._serialized_end=1075
  _globals['_MAXUSERMEMORYSIZEREQUEST']._serialized_start=1077
  _globals['_MAXUSERMEMORYSIZEREQUEST']._serialized_end=1103
  _globals['_MAXUSERMEMORYSIZERESPONSE']._serialized_start=1105
  _globals['_MAXUSERMEMORYSIZERESPONSE']._serialized_end=1183
  _globals['_SHUTDOWNREQUEST']._serialized_start=1185
  _globals['_SHUTDOWNREQUEST']._serialized_end=1217
  _globals['_SHUTDOWNRESPONSE']._serialized_start=1219
  _globals['_SHUTDOWNRESPONSE']._serialized_end=1269
  _globals['_VERSIONREQUEST']._serialized_start=1271
  _globals['_VERSIONREQUEST']._serialized_end=1287
  _globals['_VERSIONRESPONSE']._serialized_start=1289
  _globals['_VERSIONRESPONSE']._serialized_end=1380
  _globals['_PROTOCOLVERSION']._serialized_start=1382
  _globals['_PROTOCOLVERSION']._serialized_end=1444
  _globals['_AUTHENTICATEREQUEST']._serialized_start=1447
  _globals['_AUTHENTICATEREQUEST']._serialized_end=1576
  _globals['_AUTHENTICATERESPONSE']._serialized_start=1579
  _globals['_AUTHENTICATERESPONSE']._serialized_end=1725
  _globals['_KERBEROSAUTHENTICATEREQUEST']._serialized_start=1727
  _globals['_KERBEROSAUTHENTICATEREQUEST']._serialized_end=1851
  _globals['_KERBEROSAUTHENTICATERESPONSE']._serialized_start=1854
  _globals['_KERBEROSAUTHENTICATERESPONSE']._serialized_end=2027
  _globals['_CLOSESESSIONREQUEST']._serialized_start=2029
  _globals['_CLOSESESSIONREQUEST']._serialized_end=2050
  _globals['_CLOSESESSIONRESPONSE']._serialized_start=2052
  _globals['_CLOSESESSIONRESPONSE']._serialized_end=2106
  _globals['_KEEPALIVESESSIONREQUEST']._serialized_start=2108
  _globals['_KEEPALIVESESSIONREQUEST']._serialized_end=2133
  _globals['_KEEPALIVESESSIONRESPONSE']._serialized_start=2135
  _globals['_KEEPALIVESESSIONRESPONSE']._serialized_end=2193
  _globals['_GETCONFIGREQUEST']._serialized_start=2195
  _globals['_GETCONFIGREQUEST']._serialized_end=2226
  _globals['_GETCONFIGRESPONSE']._serialized_start=2229
  _globals['_GETCONFIGRESPONSE']._serialized_end=2410
  _globals['_GETCONFIGRESPONSE_ENTRIESENTRY']._serialized_start=2341
  _globals['_GETCONFIGRESPONSE_ENTRIESENTRY']._serialized_end=2410
  _globals['_SETCONFIGREQUEST']._serialized_start=2413
  _globals['_SETCONFIGREQUEST']._serialized_end=2560
  _globals['_SETCONFIGREQUEST_ENTRIESENTRY']._serialized_start=2341
  _globals['_SETCONFIGREQUEST_ENTRIESENTRY']._serialized_end=2410
  _globals['_SETCONFIGRESPONSE']._serialized_start=2562
  _globals['_SETCONFIGRESPONSE']._serialized_end=2613
  _globals['_SETDEFAULTNAMESPACEREQUEST']._serialized_start=2615
  _globals['_SETDEFAULTNAMESPACEREQUEST']._serialized_end=2670
  _globals['_SETDEFAULTNAMESPACERESPONSE']._serialized_start=2672
  _globals['_SETDEFAULTNAMESPACERESPONSE']._serialized_end=2733
  _globals['_GETDEFAULTNAMESPACEREQUEST']._serialized_start=2735
  _globals['_GETDEFAULTNAMESPACEREQUEST']._serialized_end=2763
  _globals['_GETDEFAULTNAMESPACERESPONSE']._serialized_start=2765
  _globals['_GETDEFAULTNAMESPACERESPONSE']._serialized_end=2853
  _globals['_ISADMINREQUEST']._serialized_start=2855
  _globals['_ISADMINREQUEST']._serialized_end=2871
  _globals['_ISADMINRESPONSE']._serialized_start=2873
  _globals['_ISADMINRESPONSE']._serialized_end=2940
  _globals['_ADMINSERVICE']._serialized_start=3029
  _globals['_ADMINSERVICE']._serialized_end=4413
# @@protoc_insertion_point(module_scope)
