# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: MetricsService.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'MetricsService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ErrorMessages_pb2 as ErrorMessages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14MetricsService.proto\x12\x08xgtproto\x1a\x13\x45rrorMessages.proto\"\x16\n\x14MetricsStatusRequest\"d\n\x15MetricsStatusResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.xgtproto.MetricsStatusEnum\"\x15\n\x13\x43learMetricsRequest\"6\n\x14\x43learMetricsResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error*l\n\x11MetricsStatusEnum\x12\x1a\n\x16UNKNOWN_METRICS_STATUS\x10\x00\x12\x15\n\x11METRICS_COMPLETED\x10\x01\x12\x13\n\x0fMETRICS_RUNNING\x10\x02\x12\x0f\n\x0bMETRICS_OFF\x10\x03\x32\xb8\x01\n\x0eMetricsService\x12U\n\x10GetMetricsStatus\x12\x1e.xgtproto.MetricsStatusRequest\x1a\x1f.xgtproto.MetricsStatusResponse\"\x00\x12O\n\x0c\x43learMetrics\x12\x1d.xgtproto.ClearMetricsRequest\x1a\x1e.xgtproto.ClearMetricsResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MetricsService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_METRICSSTATUSENUM']._serialized_start=260
  _globals['_METRICSSTATUSENUM']._serialized_end=368
  _globals['_METRICSSTATUSREQUEST']._serialized_start=55
  _globals['_METRICSSTATUSREQUEST']._serialized_end=77
  _globals['_METRICSSTATUSRESPONSE']._serialized_start=79
  _globals['_METRICSSTATUSRESPONSE']._serialized_end=179
  _globals['_CLEARMETRICSREQUEST']._serialized_start=181
  _globals['_CLEARMETRICSREQUEST']._serialized_end=202
  _globals['_CLEARMETRICSRESPONSE']._serialized_start=204
  _globals['_CLEARMETRICSRESPONSE']._serialized_end=258
  _globals['_METRICSSERVICE']._serialized_start=371
  _globals['_METRICSSERVICE']._serialized_end=555
# @@protoc_insertion_point(module_scope)
