# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: DataService.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'DataService.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import AdminService_pb2 as AdminService__pb2
from . import ErrorMessages_pb2 as ErrorMessages__pb2
from . import SchemaMessages_pb2 as SchemaMessages__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x44\x61taService.proto\x12\x08xgtproto\x1a\x12\x41\x64minService.proto\x1a\x13\x45rrorMessages.proto\x1a\x14SchemaMessages.proto\x1a\x1egoogle/protobuf/wrappers.proto\"N\n\x17\x46rameColumnToSourceName\x12\x19\n\x11\x66rame_column_name\x18\x01 \x01(\t\x12\x18\n\x10\x66ile_column_name\x18\x02 \x01(\t\"L\n\x16\x46rameColumnToSourceIdx\x12\x19\n\x11\x66rame_column_name\x18\x01 \x01(\t\x12\x17\n\x0f\x66ile_column_idx\x18\x02 \x01(\x04\"\xb2\x01\n\rColumnMapping\x12\x46\n\x1b\x66rame_column_to_source_name\x18\x01 \x03(\x0b\x32!.xgtproto.FrameColumnToSourceName\x12\x44\n\x1a\x66rame_column_to_source_idx\x18\x02 \x03(\x0b\x32 .xgtproto.FrameColumnToSourceIdx\x12\x13\n\x0bhas_mapping\x18\x03 \x01(\x08\"\xb1\x01\n\x17UploadRowLevelLabelInfo\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x1c\n\x14label_column_indices\x18\x02 \x03(\x03\x12\x1a\n\x12label_column_names\x18\x03 \x03(\t\x12%\n\x1dimplicit_source_vertex_labels\x18\x04 \x03(\t\x12%\n\x1dimplicit_target_vertex_labels\x18\x05 \x03(\t\"L\n\x19\x44ownloadRowLevelLabelInfo\x12\x14\n\x0c\x65gest_labels\x18\x01 \x01(\x08\x12\x19\n\x11label_header_name\x18\x02 \x01(\t\"\xb5\x04\n\x11UploadDataRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12+\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x15.xgtproto.ContentType\x12-\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x18.xgtproto.HeaderModeEnum\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\x12\x15\n\rauthorization\x18\x05 \x01(\t\x12\x19\n\x11implicit_vertices\x18\x06 \x01(\x08\x12\x35\n\nrow_labels\x18\x07 \x01(\x0b\x32!.xgtproto.UploadRowLevelLabelInfo\x12\x11\n\tdelimiter\x18\x08 \x01(\t\x12\x18\n\x10is_python_insert\x18\t \x01(\x08\x12\x11\n\tfile_path\x18\n \x01(\t\x12/\n\x0e\x63olumn_mapping\x18\x0b \x01(\x0b\x32\x17.xgtproto.ColumnMapping\x12\x17\n\x0fsuppress_errors\x18\x0c \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\r \x01(\t\x12\x12\n\nrow_filter\x18\x0e \x01(\t\x12\x37\n\x06kwargs\x18\x0f \x03(\x0b\x32\'.xgtproto.UploadDataRequest.KwargsEntry\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"]\n\x12UploadDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\xfd\x03\n\x13\x44ownloadDataRequest\x12\x17\n\x0frepository_name\x18\x01 \x01(\t\x12,\n\x06offset\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x14\n\x0cwith_headers\x18\x04 \x01(\x08\x12+\n\x0c\x63ontent_type\x18\x05 \x01(\x0e\x32\x15.xgtproto.ContentType\x12\x37\n\nrow_labels\x18\x08 \x01(\x0b\x32#.xgtproto.DownloadRowLevelLabelInfo\x12\x16\n\x0epreserve_order\x18\t \x01(\x08\x12\x1c\n\x14\x64uration_as_interval\x18\n \x01(\x08\x12\x11\n\tdelimiter\x18\x0b \x01(\t\x12\x39\n\x06kwargs\x18\x0c \x03(\x0b\x32).xgtproto.DownloadDataRequest.KwargsEntry\x12\x12\n\nrow_filter\x18\r \x01(\t\x12\x17\n\x0fwindows_newline\x18\x0e \x01(\x08\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"\x88\x01\n\x14\x44ownloadDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\'\n\njob_status\x18\x03 \x01(\x0b\x32\x13.xgtproto.JobStatus\x12\x16\n\x0enum_row_labels\x18\x04 \x01(\x05\"\xdd\x03\n\x10IngestUriRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x02 \x03(\t\x12-\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x18.xgtproto.HeaderModeEnum\x12\x15\n\rauthorization\x18\x04 \x01(\t\x12\x19\n\x11implicit_vertices\x18\x05 \x01(\x08\x12\x36\n\x06kwargs\x18\x06 \x03(\x0b\x32&.xgtproto.IngestUriRequest.KwargsEntry\x12\x35\n\nrow_labels\x18\x07 \x01(\x0b\x32!.xgtproto.UploadRowLevelLabelInfo\x12\x11\n\tdelimiter\x18\x08 \x01(\t\x12/\n\x0e\x63olumn_mapping\x18\t \x01(\x0b\x32\x17.xgtproto.ColumnMapping\x12\x17\n\x0fsuppress_errors\x18\n \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\x0b \x01(\t\x12\x12\n\nrow_filter\x18\x0c \x01(\t\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"\\\n\x11IngestUriResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\x86\x04\n\x0f\x45gestUriRequest\x12\x12\n\nframe_name\x18\x01 \x01(\t\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x14\n\x0cwith_headers\x18\x03 \x01(\x08\x12\x35\n\x06kwargs\x18\x04 \x03(\x0b\x32%.xgtproto.EgestUriRequest.KwargsEntry\x12\x37\n\nrow_labels\x18\x05 \x01(\x0b\x32#.xgtproto.DownloadRowLevelLabelInfo\x12\x16\n\x0epreserve_order\x18\x06 \x01(\x08\x12\x17\n\x0fnumber_of_files\x18\x07 \x01(\x04\x12,\n\x06offset\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12,\n\x06length\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1c\n\x14\x64uration_as_interval\x18\n \x01(\x08\x12\x11\n\tdelimiter\x18\x0b \x01(\t\x12\x12\n\nrow_filter\x18\x0c \x01(\t\x12\x15\n\rauthorization\x18\r \x01(\t\x12\x17\n\x0fwindows_newline\x18\x0e \x01(\x08\x1a\x44\n\x0bKwargsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.xgtproto.ConfigValue:\x02\x38\x01\"[\n\x10\x45gestUriResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\x80\x01\n\x12InferSchemaRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12-\n\x0bheader_mode\x18\x02 \x01(\x0e\x32\x18.xgtproto.HeaderModeEnum\x12\x11\n\tdelimiter\x18\x03 \x01(\t\x12\x15\n\rauthorization\x18\x04 \x01(\t\"j\n\x13InferSchemaResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12 \n\x06schema\x18\x02 \x01(\x0b\x32\x10.xgtproto.Schema\x12\x11\n\tdelimiter\x18\x03 \x03(\t\"m\n\x07SSLInfo\x12\x0e\n\x06\x64o_ssl\x18\x01 \x01(\x08\x12\x12\n\nchain_cert\x18\x02 \x01(\x0c\x12\x12\n\nclient_key\x18\x03 \x01(\x0c\x12\x13\n\x0b\x63lient_cert\x18\x04 \x01(\x0c\x12\x15\n\rssl_server_cn\x18\x05 \x01(\t\"3\n\x0cUserAuthInfo\x12\x11\n\tuser_name\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\xa1\x01\n\x1fTransferFrameArrowClientRequest\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x04\x12\x17\n\x0frepository_name\x18\x03 \x01(\t\x12\x1e\n\x03ssl\x18\x04 \x01(\x0b\x32\x11.xgtproto.SSLInfo\x12)\n\tuser_auth\x18\x05 \x01(\x0b\x32\x16.xgtproto.UserAuthInfo\"k\n TransferFrameArrowClientResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\xe4\x03\n\x19UploadCSVMultiDataRequest\x12\x12\n\nframe_name\x18\x01 \x03(\t\x12+\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x15.xgtproto.ContentType\x12-\n\x0bheader_mode\x18\x03 \x01(\x0e\x32\x18.xgtproto.HeaderModeEnum\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\x12\x19\n\x11implicit_vertices\x18\x05 \x01(\x08\x12\x11\n\tdelimiter\x18\x06 \x01(\t\x12\x18\n\x10is_python_insert\x18\x07 \x01(\x08\x12\x11\n\tfile_path\x18\x08 \x01(\t\x12\x17\n\x0fsuppress_errors\x18\t \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\n \x01(\t\x12\x15\n\rstream_length\x18\x0b \x03(\x04\x12P\n\x0f\x63olumn_mappings\x18\x0c \x03(\x0b\x32\x37.xgtproto.UploadCSVMultiDataRequest.ColumnMappingsEntry\x1aN\n\x13\x43olumnMappingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.xgtproto.ColumnMapping:\x02\x38\x01\"e\n\x1aUploadCSVMultiDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus\"\xdd\x02\n\x1bUploadArrowMultiDataRequest\x12\x12\n\nframe_name\x18\x01 \x03(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\x19\n\x11implicit_vertices\x18\x03 \x01(\x08\x12\x11\n\tfile_path\x18\x04 \x01(\t\x12\x17\n\x0fsuppress_errors\x18\x05 \x01(\x08\x12\x19\n\x11on_duplicate_keys\x18\x06 \x01(\t\x12R\n\x0f\x63olumn_mappings\x18\x07 \x03(\x0b\x32\x39.xgtproto.UploadArrowMultiDataRequest.ColumnMappingsEntry\x12\x13\n\x0bnum_batches\x18\x08 \x03(\x04\x1aN\n\x13\x43olumnMappingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.xgtproto.ColumnMapping:\x02\x38\x01\"g\n\x1cUploadArrowMultiDataResponse\x12\x1e\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x0f.xgtproto.Error\x12\'\n\njob_status\x18\x02 \x01(\x0b\x32\x13.xgtproto.JobStatus*_\n\x0eHeaderModeEnum\x12\x17\n\x13UNKNOWN_HEADER_MODE\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x12\n\x0eIGNORE_HEADERS\x10\x02\x12\n\n\x06NORMAL\x10\x03\x12\n\n\x06STRICT\x10\x04*R\n\x0b\x43ontentType\x12\x13\n\x0fUNKNOWN_CONTENT\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\x08\n\x04JSON\x10\x02\x12\x07\n\x03ZIP\x10\x03\x12\x08\n\x04GZIP\x10\x04\x12\x08\n\x04TZIP\x10\x05\x32\xcf\x05\n\x0b\x44\x61taService\x12K\n\nUploadData\x12\x1b.xgtproto.UploadDataRequest\x1a\x1c.xgtproto.UploadDataResponse\"\x00(\x01\x12Q\n\x0c\x44ownloadData\x12\x1d.xgtproto.DownloadDataRequest\x1a\x1e.xgtproto.DownloadDataResponse\"\x00\x30\x01\x12H\n\tIngestUri\x12\x1a.xgtproto.IngestUriRequest\x1a\x1b.xgtproto.IngestUriResponse\"\x00(\x01\x12\x43\n\x08\x45gestUri\x12\x19.xgtproto.EgestUriRequest\x1a\x1a.xgtproto.EgestUriResponse\"\x00\x12L\n\x0bInferSchema\x12\x1c.xgtproto.InferSchemaRequest\x1a\x1d.xgtproto.InferSchemaResponse\"\x00\x12s\n\x18TransferFrameArrowClient\x12).xgtproto.TransferFrameArrowClientRequest\x1a*.xgtproto.TransferFrameArrowClientResponse\"\x00\x12\x63\n\x12UploadCSVMultiData\x12#.xgtproto.UploadCSVMultiDataRequest\x1a$.xgtproto.UploadCSVMultiDataResponse\"\x00(\x01\x12i\n\x14UploadArrowMultiData\x12%.xgtproto.UploadArrowMultiDataRequest\x1a&.xgtproto.UploadArrowMultiDataResponse\"\x00(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'DataService_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UPLOADDATAREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_UPLOADDATAREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_DOWNLOADDATAREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_DOWNLOADDATAREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_INGESTURIREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_INGESTURIREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_EGESTURIREQUEST_KWARGSENTRY']._loaded_options = None
  _globals['_EGESTURIREQUEST_KWARGSENTRY']._serialized_options = b'8\001'
  _globals['_UPLOADCSVMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._loaded_options = None
  _globals['_UPLOADCSVMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_options = b'8\001'
  _globals['_UPLOADARROWMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._loaded_options = None
  _globals['_UPLOADARROWMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_options = b'8\001'
  _globals['_HEADERMODEENUM']._serialized_start=4948
  _globals['_HEADERMODEENUM']._serialized_end=5043
  _globals['_CONTENTTYPE']._serialized_start=5045
  _globals['_CONTENTTYPE']._serialized_end=5127
  _globals['_FRAMECOLUMNTOSOURCENAME']._serialized_start=126
  _globals['_FRAMECOLUMNTOSOURCENAME']._serialized_end=204
  _globals['_FRAMECOLUMNTOSOURCEIDX']._serialized_start=206
  _globals['_FRAMECOLUMNTOSOURCEIDX']._serialized_end=282
  _globals['_COLUMNMAPPING']._serialized_start=285
  _globals['_COLUMNMAPPING']._serialized_end=463
  _globals['_UPLOADROWLEVELLABELINFO']._serialized_start=466
  _globals['_UPLOADROWLEVELLABELINFO']._serialized_end=643
  _globals['_DOWNLOADROWLEVELLABELINFO']._serialized_start=645
  _globals['_DOWNLOADROWLEVELLABELINFO']._serialized_end=721
  _globals['_UPLOADDATAREQUEST']._serialized_start=724
  _globals['_UPLOADDATAREQUEST']._serialized_end=1289
  _globals['_UPLOADDATAREQUEST_KWARGSENTRY']._serialized_start=1221
  _globals['_UPLOADDATAREQUEST_KWARGSENTRY']._serialized_end=1289
  _globals['_UPLOADDATARESPONSE']._serialized_start=1291
  _globals['_UPLOADDATARESPONSE']._serialized_end=1384
  _globals['_DOWNLOADDATAREQUEST']._serialized_start=1387
  _globals['_DOWNLOADDATAREQUEST']._serialized_end=1896
  _globals['_DOWNLOADDATAREQUEST_KWARGSENTRY']._serialized_start=1221
  _globals['_DOWNLOADDATAREQUEST_KWARGSENTRY']._serialized_end=1289
  _globals['_DOWNLOADDATARESPONSE']._serialized_start=1899
  _globals['_DOWNLOADDATARESPONSE']._serialized_end=2035
  _globals['_INGESTURIREQUEST']._serialized_start=2038
  _globals['_INGESTURIREQUEST']._serialized_end=2515
  _globals['_INGESTURIREQUEST_KWARGSENTRY']._serialized_start=1221
  _globals['_INGESTURIREQUEST_KWARGSENTRY']._serialized_end=1289
  _globals['_INGESTURIRESPONSE']._serialized_start=2517
  _globals['_INGESTURIRESPONSE']._serialized_end=2609
  _globals['_EGESTURIREQUEST']._serialized_start=2612
  _globals['_EGESTURIREQUEST']._serialized_end=3130
  _globals['_EGESTURIREQUEST_KWARGSENTRY']._serialized_start=1221
  _globals['_EGESTURIREQUEST_KWARGSENTRY']._serialized_end=1289
  _globals['_EGESTURIRESPONSE']._serialized_start=3132
  _globals['_EGESTURIRESPONSE']._serialized_end=3223
  _globals['_INFERSCHEMAREQUEST']._serialized_start=3226
  _globals['_INFERSCHEMAREQUEST']._serialized_end=3354
  _globals['_INFERSCHEMARESPONSE']._serialized_start=3356
  _globals['_INFERSCHEMARESPONSE']._serialized_end=3462
  _globals['_SSLINFO']._serialized_start=3464
  _globals['_SSLINFO']._serialized_end=3573
  _globals['_USERAUTHINFO']._serialized_start=3575
  _globals['_USERAUTHINFO']._serialized_end=3626
  _globals['_TRANSFERFRAMEARROWCLIENTREQUEST']._serialized_start=3629
  _globals['_TRANSFERFRAMEARROWCLIENTREQUEST']._serialized_end=3790
  _globals['_TRANSFERFRAMEARROWCLIENTRESPONSE']._serialized_start=3792
  _globals['_TRANSFERFRAMEARROWCLIENTRESPONSE']._serialized_end=3899
  _globals['_UPLOADCSVMULTIDATAREQUEST']._serialized_start=3902
  _globals['_UPLOADCSVMULTIDATAREQUEST']._serialized_end=4386
  _globals['_UPLOADCSVMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_start=4308
  _globals['_UPLOADCSVMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_end=4386
  _globals['_UPLOADCSVMULTIDATARESPONSE']._serialized_start=4388
  _globals['_UPLOADCSVMULTIDATARESPONSE']._serialized_end=4489
  _globals['_UPLOADARROWMULTIDATAREQUEST']._serialized_start=4492
  _globals['_UPLOADARROWMULTIDATAREQUEST']._serialized_end=4841
  _globals['_UPLOADARROWMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_start=4308
  _globals['_UPLOADARROWMULTIDATAREQUEST_COLUMNMAPPINGSENTRY']._serialized_end=4386
  _globals['_UPLOADARROWMULTIDATARESPONSE']._serialized_start=4843
  _globals['_UPLOADARROWMULTIDATARESPONSE']._serialized_end=4946
  _globals['_DATASERVICE']._serialized_start=5130
  _globals['_DATASERVICE']._serialized_end=5849
# @@protoc_insertion_point(module_scope)
